==> datadog-api-client-2.2.0-sources.jar: com/datadog/api/client/v1/model/SyntheticsPrivateLocationSecrets.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.util.Objects;

/**
 * Secrets for the private location. Only present in the response when creating the private
 * location.
 */
@JsonPropertyOrder({
  SyntheticsPrivateLocationSecrets.JSON_PROPERTY_AUTHENTICATION,
  SyntheticsPrivateLocationSecrets.JSON_PROPERTY_CONFIG_DECRYPTION
})
@jakarta.annotation.Generated(
    value = "https://github.com/DataDog/datadog-api-client-java/blob/master/.generator")
public class SyntheticsPrivateLocationSecrets {
  @JsonIgnore public boolean unparsed = false;
  public static final String JSON_PROPERTY_AUTHENTICATION = "authentication";
  private SyntheticsPrivateLocationSecretsAuthentication authentication;

  public static final String JSON_PROPERTY_CONFIG_DECRYPTION = "config_decryption";
  private SyntheticsPrivateLocationSecretsConfigDecryption configDecryption;

  public SyntheticsPrivateLocationSecrets authentication(
      SyntheticsPrivateLocationSecretsAuthentication authentication) {
    this.authentication = authentication;
    this.unparsed |= authentication.unparsed;
    return this;
  }

  /**
   * Authentication part of the secrets.
   *
   * @return authentication
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_AUTHENTICATION)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public SyntheticsPrivateLocationSecretsAuthentication getAuthentication() {
    return authentication;
  }

  public void setAuthentication(SyntheticsPrivateLocationSecretsAuthentication authentication) {
    this.authentication = authentication;
  }

  public SyntheticsPrivateLocationSecrets configDecryption(
      SyntheticsPrivateLocationSecretsConfigDecryption configDecryption) {
    this.configDecryption = configDecryption;
    this.unparsed |= configDecryption.unparsed;
    return this;
  }

  /**
   * Private key for the private location.
   *
   * @return configDecryption
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_CONFIG_DECRYPTION)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public SyntheticsPrivateLocationSecretsConfigDecryption getConfigDecryption() {
    return configDecryption;
  }

  public void setConfigDecryption(
      SyntheticsPrivateLocationSecretsConfigDecryption configDecryption) {
    this.configDecryption = configDecryption;
  }

  /** Return true if this SyntheticsPrivateLocationSecrets object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    SyntheticsPrivateLocationSecrets syntheticsPrivateLocationSecrets =
        (SyntheticsPrivateLocationSecrets) o;
    return Objects.equals(this.authentication, syntheticsPrivateLocationSecrets.authentication)
        && Objects.equals(this.configDecryption, syntheticsPrivateLocationSecrets.configDecryption);
  }

  @Override
  public int hashCode() {
    return Objects.hash(authentication, configDecryption);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class SyntheticsPrivateLocationSecrets {\n");
    sb.append("    authentication: ").append(toIndentedString(authentication)).append("\n");
    sb.append("    configDecryption: ").append(toIndentedString(configDecryption)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> datadog-api-client-2.28.0-sources.jar: com/datadog/api/client/v1/model/SyntheticsPrivateLocationSecrets.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v1.model;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * Secrets for the private location. Only present in the response when creating the private
 * location.
 */
@JsonPropertyOrder({
  SyntheticsPrivateLocationSecrets.JSON_PROPERTY_AUTHENTICATION,
  SyntheticsPrivateLocationSecrets.JSON_PROPERTY_CONFIG_DECRYPTION
})
@jakarta.annotation.Generated(
    value = "https://github.com/DataDog/datadog-api-client-java/blob/master/.generator")
public class SyntheticsPrivateLocationSecrets {
  @JsonIgnore public boolean unparsed = false;
  public static final String JSON_PROPERTY_AUTHENTICATION = "authentication";
  private SyntheticsPrivateLocationSecretsAuthentication authentication;

  public static final String JSON_PROPERTY_CONFIG_DECRYPTION = "config_decryption";
  private SyntheticsPrivateLocationSecretsConfigDecryption configDecryption;

  public SyntheticsPrivateLocationSecrets authentication(
      SyntheticsPrivateLocationSecretsAuthentication authentication) {
    this.authentication = authentication;
    this.unparsed |= authentication.unparsed;
    return this;
  }

  /**
   * Authentication part of the secrets.
   *
   * @return authentication
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_AUTHENTICATION)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public SyntheticsPrivateLocationSecretsAuthentication getAuthentication() {
    return authentication;
  }

  public void setAuthentication(SyntheticsPrivateLocationSecretsAuthentication authentication) {
    this.authentication = authentication;
  }

  public SyntheticsPrivateLocationSecrets configDecryption(
      SyntheticsPrivateLocationSecretsConfigDecryption configDecryption) {
    this.configDecryption = configDecryption;
    this.unparsed |= configDecryption.unparsed;
    return this;
  }

  /**
   * Private key for the private location.
   *
   * @return configDecryption
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_CONFIG_DECRYPTION)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public SyntheticsPrivateLocationSecretsConfigDecryption getConfigDecryption() {
    return configDecryption;
  }

  public void setConfigDecryption(
      SyntheticsPrivateLocationSecretsConfigDecryption configDecryption) {
    this.configDecryption = configDecryption;
  }

  /**
   * A container for additional, undeclared properties. This is a holder for any undeclared
   * properties as specified with the 'additionalProperties' keyword in the OAS document.
   */
  private Map<String, Object> additionalProperties;

  /**
   * Set the additional (undeclared) property with the specified name and value. If the property
   * does not already exist, create it otherwise replace it.
   *
   * @param key The arbitrary key to set
   * @param value The associated value
   * @return SyntheticsPrivateLocationSecrets
   */
  @JsonAnySetter
  public SyntheticsPrivateLocationSecrets putAdditionalProperty(String key, Object value) {
    if (this.additionalProperties == null) {
      this.additionalProperties = new HashMap<String, Object>();
    }
    this.additionalProperties.put(key, value);
    return this;
  }

  /**
   * Return the additional (undeclared) property.
   *
   * @return The additional properties
   */
  @JsonAnyGetter
  public Map<String, Object> getAdditionalProperties() {
    return additionalProperties;
  }

  /**
   * Return the additional (undeclared) property with the specified name.
   *
   * @param key The arbitrary key to get
   * @return The specific additional property for the given key
   */
  public Object getAdditionalProperty(String key) {
    if (this.additionalProperties == null) {
      return null;
    }
    return this.additionalProperties.get(key);
  }

  /** Return true if this SyntheticsPrivateLocationSecrets object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    SyntheticsPrivateLocationSecrets syntheticsPrivateLocationSecrets =
        (SyntheticsPrivateLocationSecrets) o;
    return Objects.equals(this.authentication, syntheticsPrivateLocationSecrets.authentication)
        && Objects.equals(this.configDecryption, syntheticsPrivateLocationSecrets.configDecryption)
        && Objects.equals(
            this.additionalProperties, syntheticsPrivateLocationSecrets.additionalProperties);
  }

  @Override
  public int hashCode() {
    return Objects.hash(authentication, configDecryption, additionalProperties);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class SyntheticsPrivateLocationSecrets {\n");
    sb.append("    authentication: ").append(toIndentedString(authentication)).append("\n");
    sb.append("    configDecryption: ").append(toIndentedString(configDecryption)).append("\n");
    sb.append("    additionalProperties: ")
        .append(toIndentedString(additionalProperties))
        .append("\n");
    sb.append('}');
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
